@@ -20,10 +20,19 @@ namespace atlas {
 
 class Plugin : public eckit::system::Library {
 public:
+    /// @param [in] name    Plugin name
+    /// @param [in] libname Library name as will be used in file system
     Plugin( const std::string& name, const std::string& libname = "" );
+
+    /// @brief Plugin name
     const std::string& name() const { return name_; }
+
+    /// @brief Library name as will be used in file system
     const std::string& libraryName() const { return libname_; }
 
+private:
+    const void* addr() const override;
+
 private:
     std::string name_;
     std::string libname_;
